Package: estadistica
Type: Package
Title: Fundamentos de estadística descriptiva e inferencial
Version: 1.2.2
Authors@R: 
  c(person(given = "Vicente",
           family = "Coll-Serrano",
           role = c("aut", "cre"),
           email = "estadistic@uv.es"),
    person(given = "Rosario",
           family = "Martínez Verdú",
           role = "aut"))
Author: Vicente Coll-Serrano [aut, cre],
  Rosario Martínez Verdú [aut]
Description: Este paquete pretende apoyar el proceso enseñanza-aprendizaje de estadística descriptiva e inferencial. Las funciones contenidas en el paquete 'estadistica' cubren los conceptos básicos estudiados en un curso introductorio. Muchos conceptos son ilustrados con gráficos dinámicos o web apps para facilitar su comprensión. This package aims to help the teaching-learning process of descriptive and inferential statistics. The functions contained in the package 'estadistica' cover the basic concepts studied in a statistics introductory course. Many concepts are illustrated with dynamic graphs or web apps to make the understanding easier. See: Esteban et al. (2005, ISBN: 9788497323741), Newbold et al.(2019, ISBN:9781292315034 ), Murgui et al. (2002, ISBN:9788484424673) .
License: GPL-3
Encoding: UTF-8
Language: es, en
LazyData: true
RoxygenNote: 7.3.3
URL: https://www.uv.es/estadistic/
Depends: R (>= 3.5.0)
Imports: cli, dplyr, tidyr, tibble, plotly, ggplot2, rio, shiny,
        shinydashboard, knitr, forecast, openxlsx, cowplot
NeedsCompilation: no
Packaged: 2026-04-25 03:11:07 UTC; vicen
Maintainer: Vicente Coll-Serrano <estadistic@uv.es>
Repository: CRAN
Date/Publication: 2026-04-25 03:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 02:05:34 UTC; unix
