# Generated by roxygen2: do not edit by hand

export(calculo.probabilidad)
export(coeficiente.variacion)
export(contraste.correlacion)
export(contraste.diferencia.medias)
export(contraste.diferencia.proporciones)
export(contraste.media)
export(contraste.proporcion)
export(contraste.razon.varianzas)
export(contraste.varianza)
export(contraste_bondad)
export(contraste_bondad_cat)
export(contraste_homogeneidad)
export(contraste_independencia)
export(convergencia.varianza)
export(correlacion)
export(covarianza)
export(cuantiles)
export(desviacion)
export(distribucion.normal)
export(distribuciones.probabilidad)
export(ic.correlacion)
export(ic.diferencia.medias)
export(ic.diferencia.proporciones)
export(ic.media)
export(ic.proporcion)
export(ic.razon.varianzas)
export(ic.varianza)
export(leer.datos)
export(matriz.correlacion)
export(matriz.covar)
export(media)
export(mediana)
export(medidas.forma)
export(moda)
export(muestra)
export(nivel.confianza)
export(regresion.simple)
export(resumen.descriptivos)
export(resumir)
export(series.temporales)
export(tabla.bidimensional)
export(tabla.frecuencias)
export(unir.vectores)
export(varianza)
import(cowplot)
import(dplyr)
import(ggplot2)
import(knitr)
import(openxlsx)
import(shiny)
import(shinydashboard)
import(tibble)
import(tidyr)
importFrom(stats,addmargins)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dbinom)
importFrom(stats,dchisq)
importFrom(stats,df)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,dt)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_longer)
importFrom(utils,capture.output)
importFrom(utils,edit)
