utils::globalVariables(c("ni", "fi", "sumatorio", "variable2",
                         "frecuencia", "valor", "cuantiles_int",
                         "filas", "columnas", "name","rbindlist",
                         "y","var_muestra","media_x","sumatorio3","sumatorio4","desv.x.muestra","asimetria_soft",
                         "curtosis_soft","error_curtosis","ic","inferior","superior", "color","varianza.muestral",
                         "media.muestral","incluido","value",
                         "grupo","grupo2","vx","vy","coeficiente.determinacion",
                         "varianza.regresion","valores.teoricos","errores",
                         "obs","id","sc.observados","sc.teoricos","errores2","suma.cuadrados.total",
                         "suma.cuadrados.errores","suma.cuadrados.regresion","varianza.residual",
                         "varianza.residuos", "leverage", "puntos.palanca","error.norm",
                         "X","momento", "atipico", "lm", "mediamovil", "paso1_ive",
                         "periodo", "pivot_wider", "matriz","variable_serie",
                         "A1","A2","c1","c2","c3","error_asimetria","var_coef","prediccion",".",
                         "variable1","variable2","..density.."))
