% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unir.vectores.R
\name{unir.vectores}
\alias{unir.vectores}
\title{Unir vectores.}
\usage{
unir.vectores(...)
}
\arguments{
\item{...}{Introducir los nombres de los objetos, vectores, que se quiere unir. Si los vectores tienen distinta longitud se rellenarán los espacios con NAs.}
}
\value{
La función devuelve un dataframe.
}
\description{
Une dos o más vectores numéricos de igual o distinta longitud.

\if{html}{\figure{qrleerdatos.png}{width = 200px}}
\if{latex}{\figure{qrleerdatos.png}{options: width=3cm}}
}
\author{
\strong{Vicente Coll-Serrano}.
\emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}

\strong{Rosario Martínez Verdú}.
\emph{Economía Aplicada.}

Facultad de Economía. Universidad de Valencia (España)
}
