% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/leer.datos.R
\name{leer.datos}
\alias{leer.datos}
\title{Leer datos.}
\usage{
leer.datos(introducir = FALSE, pos = 1)
}
\arguments{
\item{introducir}{Valor lógico. Si \code{introducir = FALSE} (por defecto), se abrirá una ventana para que el usuario seleccione el fichero de datos que quiere cargar. Si \code{introducir = TRUE}, el usuario introducirá él mismo los datos.}

\item{pos}{Es un valor fijo utilizado para mostrar el dataframe del usuario en el Global Environment.}
}
\value{
Al finalizar el proceso de lectura de datos se mostrará el dataframe cargado en el environment.
}
\description{
Carga un conjunto de datos.

\if{html}{\figure{qrleerdatos.png}{width = 200px}}
\if{latex}{\figure{qrleerdatos.png}{options: width=3cm}}
}
\references{
Esteban García, J. et al. (2005). Estadística descriptiva y nociones de probabilidad. Thomson.
}
\author{
\strong{Vicente Coll-Serrano}.
\emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}

\strong{Rosario Martínez Verdú}.
\emph{Economía Aplicada.}

\strong{Cristina Pardo-García}.
\emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}

Facultad de Economía. Universidad de Valencia (España)
}
