% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/contraste.razon.varianzas.R
\name{contraste.razon.varianzas}
\alias{contraste.razon.varianzas}
\title{Contraste de hipótesis sobre la razón de varianzas.}
\usage{
contraste.razon.varianzas(
  x,
  variable = NULL,
  introducir = FALSE,
  hipotesis_nula = 1,
  tipo_contraste = c("bilateral", "cola derecha", "cola izquierda"),
  alfa = 0.05,
  grafico = FALSE
)
}
\arguments{
\item{x}{Conjunto de datos. Puede ser un vector o un dataframe.}

\item{variable}{Es un vector (numérico o carácter) que indica las variables a seleccionar de \code{x}. Si \code{x} se refiere solo a dos variables, \code{variable = NULL}. En caso contrario, es necesario indicar el nombre o posición (número de columna) de las variables.}

\item{introducir}{Valor lógico. Si \code{introducir = FALSE} (por defecto), el usuario debe indicar el conjunto de datos que desea analizar usando los argumentos \code{x} y/o \code{variable}. Si \code{introducir = TRUE}, se le solicitará al ususario que introduzca la información relevante sobre tamaño muestral, valor de la media muestral, etc.}

\item{hipotesis_nula}{Es un valor numérico. Por defecto el valor está fijado a 1, es decir, igualdad de varianzas.}

\item{tipo_contraste}{Es un carácter. Indica el tipo de contraste a realizar. Por defecto, \code{tipo_contraste = "bilateral"}.
Si \code{tipo_contraste = "bilateral"}, se contraste la hipótesis nula igual un valor frente a la alternativa distinto de dicho valor.
Si \code{tipo_contraste = "cola derecha"}, se contrasta la hipótesis nula menor o igual a un valor frente a la alternativa mayor a dicho valor.
Si \code{tipo_contraste = "cola izquierda"}, se contrasta la hipótesis nula mayor o igual a un valor frente a la alternativa menos a dicho valor.}

\item{alfa}{Es un valor numérico entre 0 y 1. Indica el nivel de significación. Por defecto, \code{alfa = 0.05} (5 por ciento)}

\item{grafico}{Es un valor lógico. Por defecto \code{grafico = FALSE}. Si se quiere obtener una representación gráfica del contraste realizado, cambiar el argumento a \code{grafico = TRUE}. Nota: Esta opción no está implementada para todos los casos.}
}
\value{
La función devuelve un objeto de la clase \code{list}. La lista contendrá información sobre: la hipótesis nula contrastada, el estadístico de prueba, el p-valor y  el intervalo de confianza para la media muestral supuesta cierta la hipótesis nula. Si \code{grafico=TRUE} se incluirá una representación gráfica de la región de aceptación-rechazo con los valores críticos.
}
\description{
Realiza el contraste de hipótesis sobre la razón de dos varianzas poblacionales.

Lee el código QR para video-tutorial sobre el uso de la función con un ejemplo.

\if{html}{\figure{qrcrazonvarianzas.png}{width = 200px}}
\if{latex}{\figure{qrcrazonvarianzas.png}{options: width=3cm}}
}
\details{
La hipótesis nula que se considera en el contraste bilateral es:

\if{html}{\figure{crazonvar.png}{width = 240px}}
\if{latex}{\figure{crazonvar.png}{options: width=3cm}}

El estadístico F es:

(1) Si trabajamos con la varianza muestral:


\if{html}{\figure{crazonvarmuestra.png}{width = 400px}}
\if{latex}{\figure{crazonvarmuestra.png}{options: width=5cm}}

(2) si trabajamos con la cuasi-varianza muestral:

\if{html}{\figure{crazonvarcuasi.png}{width = 200px}}
\if{latex}{\figure{crazonvarcuasi.png}{options: width=3cm}}

Tanto en (1) como en (2) el estadístico F se distribuye como una F con (n1-1) grados de libertad en el numerador y (n2-1) grados de libertad en el denominador.
}
\references{
Casas José M. (1997) Inferencia estadística. Editorial: Centro de estudios Ramón Areces, S.A. ISBN: 848004263-X

Esteban García, J. et al. (2008). Curso básico de inferencia estadística. ReproExprés, SL. ISBN: 8493036595.

Murgui, J.S. y otros. (2002). Ejercicios de estadística Economía y Ciencias sociales. tirant lo blanch. ISBN: 9788484424673

Newbold, P, Carlson, W. y Thorne, B. (2019). Statistics for Business and Economics, Global Edition. Pearson. ISBN: 9781292315034
}
\seealso{
\code{\link{ic.razon.varianzas}}
}
\author{
\strong{Vicente Coll-Serrano}.
\emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}

\strong{Rosario Martínez Verdú}.
\emph{Economía Aplicada.}

Facultad de Economía. Universidad de Valencia (España)
}
