% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tabla.frecuencias.R
\name{tabla.frecuencias}
\alias{tabla.frecuencias}
\title{Tabla de frecuencias.}
\usage{
tabla.frecuencias(x, eliminar.na = TRUE, grafico = FALSE, exportar = FALSE)
}
\arguments{
\item{x}{Conjunto de datos. Puede ser un vector (numérico o factor) o un dataframe. Si el dataframe tiene más de una variable, solicitará al usuario que idenfique el nombre de la variable para la que se quiere calcular la tabla de frecuencias.}

\item{eliminar.na}{Valor lógico. Por defecto \code{eliminar.na = TRUE}. Si se quiere obtener la tabla de frecuencias con NAs, cambiar el argumento a \code{eliminar.na = FALSE}.}

\item{grafico}{Si \code{grafico = TRUE}, representa el histograma o el gráfico de barras de la variable seleccionada.}

\item{exportar}{Para exportar los resultados a una hoja de cálculo Excel (\code{exportar = TRUE}).}
}
\value{
Devuelve la tabla de frecuencias como una \code{tibble}. Si \code{grafico = TRUE}, se devuelve en una lista la tabla de frecuencias y su representación gráfica.
}
\description{
Esta función presenta la distribución de frecuencias de una variable cuantitativa o cualitativa.

Lee el código QR para video-tutorial sobre el uso de la función con un ejemplo.

\if{html}{\figure{qrtablafrecuencias.png}{width = 200px}}
\if{latex}{\figure{qrtablafrecuencias.png}{options: width=3cm}}
}
\references{
Esteban García, J. y otros. (2005). Estadística descriptiva y nociones de probabilidad. Paraninfo. ISBN: 9788497323741

Newbold, P, Carlson, W. y Thorne, B. (2019). Statistics for Business and Economics, Global Edition. Pearson. ISBN: 9781292315034

Murgui, J.S. y otros. (2002). Ejercicios de estadística Economía y Ciencias sociales. tirant lo blanch. ISBN: 9788484424673
}
\author{
\strong{Vicente Coll-Serrano}.
\emph{Métodos Cuantitativos para la Medición de la Cultura (MC2). Economía Aplicada.}

\strong{Rosario Martínez Verdú}.
\emph{Economía Aplicada.}

Facultad de Economía. Universidad de Valencia (España)
}
